@@ -3,4 +3,8 @@ from .efficientsam import EfficientSam30m  # noqa: F401
 from .sam import Sam100m  # noqa: F401
 from .sam import Sam300m  # noqa: F401
 from .sam import Sam600m  # noqa: F401
+from .sam2 import Sam2BasePlus  # noqa: F401
+from .sam2 import Sam2Large  # noqa: F401
+from .sam2 import Sam2Small  # noqa: F401
+from .sam2 import Sam2Tiny  # noqa: F401
 from .yoloworld import YoloWorldXL  # noqa: F401
